# Thorn Remastered

![Thorn Remastered Logo](https://github.com/RoseInjector/Thorn-Remastered-/assets/138173273/a742dc9c-598e-46dd-a526-fe158b0cbf05)

**Thorn Remastered** is an enhanced version of the original Thorn.py project, designed to simplify web scraping tasks by providing a versatile set of tools.

## Features

- Scrapes a wide range of content types, including HTML, JSON, CSS, and more.
- Image scraping capabilities for downloading images from websites.
- User-friendly and interactive command-line interface.
- Flexible and extensible architecture for adding new scraping functionality.
- Built-in error handling to ensure robust scraping.

## Installation

You can install Thorn Remastered via pip:

```bash
pip install thorn.py-remast
```

## Usage

Here are some examples of how to use Thorn Remastered:

### Scraping HTML

```python
from thorn import Thorn

thorn = Thorn()
html_content = thorn.scrape_html("https://example.com")
print(html_content)
```

### Scraping JSON

```python
from thorn import Thorn

thorn = Thorn()
json_data = thorn.scrape_json("https://api.example.com/data.json")
print(json_data)
```

### Scraping Images

```python
from thorn import ImageThorn

image_thorn = ImageThorn()
image_thorn.scrape_images("https://example.com", output_folder="./example_images")
```

### Scraping Python Code

```python
from thorn import Thorn

thorn = Thorn()
python_code = thorn.scrape_python("https://raw.githubusercontent.com/example/repo/main/script.py")
print(python_code)
```

## Contributing

Contributions are welcome! Feel free to open issues, submit pull requests, or suggest improvements.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## Acknowledgments

Special thanks to the original Thorn.py project for inspiration.

---

**Note:** Always ensure compliance with website terms of service and legal regulations when performing web scraping.

## Table of Contents

- [Features](#features)
- [Installation](#installation)
- [Usage](#usage)
  - [Scraping HTML](#scraping-html)
  - [Scraping JSON](#scraping-json)
  - [Scraping Images](#scraping-images)
  - [Scraping Python Code](#scraping-python-code)
- [Contributing](#contributing)
- [License](#license)
- [Acknowledgments](#acknowledgments)
```
